# Test Coverage Report: excluded packages and modules

Generated: Mon 2013-04-29 18:13 CST

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- auction.admin
- auction.migrations
- auction.tests
- auction.urls
- auction.utils.__init__
- django.contrib.admin
- django.contrib.admindocs
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.messages
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- django.contrib.staticfiles

Back to index.